[Python-Markdown](https://github.com/Python-Markdown/markdown) plugin for Jira wiki syntax

Adds support for :
 * {{monospace text}}
 * {code} code blocks {code}

Does not support multi-paragraph code blocks (double newline in a code block).
